window.Gleam.initSearch([{"doc":"lustre","title":"lustre","content":"# Lustre\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre)](https://hex.pm/packages/lustre)\n\nAn Elm-inspired framework for building web apps in Gleam!\n\n```gleam\nimport gleam/int\nimport lustre\nimport lustre/element.{text}\nimport lustre/element/html.{div, button, p}\nimport lustre/event.{on_click}\n\npub fn main() {\n  let app = lustre.simple(init, update, view)\n  let assert Ok(_) = lustre.start(&quot;[data-lustre-app]&quot;, Nil)\n\n  Nil\n}\n\nfn init(_) {\n  0\n}\n\ntype Msg {\n  Incr\n  Decr\n}\n\nfn update(model, msg) {\n  case msg {\n    Incr -&gt; model + 1\n    Decr -&gt; model - 1\n  }\n}\n\nfn view(model) {\n  let count = int.to_string(model)\n\n  div([], [\n    button([on_click(Decr)], [text(&quot; + &quot;)]),\n    p([], [text(count)]),\n    button([on_click(Incr)], [text(&quot; - &quot;)])\n  ])\n}\n```\n\n## Documentation\n\nYou can find the official documentation over at [lustre.build](https://lustre.build). Note\nthat if you&#39;re viewing the documentation published on [Hexdocs](https://hexdocs.pm/lustre/index.html),\nyou may find that things are missing! Because of the way Gleam&#39;s documentation is\ngenerated, packages and functions that target _only_ JavaScript don&#39;t get documented.\n\n## Installation\n\nLustre is available on [Hex](https://hex.pm/packages/lustre). You can install\nit like any other Hex package:\n\n```sh\n$ gleam add lustre\n```\n","url":"index.html"},{"doc":"lustre/effect","title":"Effect","content":"pub opaque type Effect(msg)\n\n\nSynonyms:\nlustre/effect.Effect\nlustre/effect Effect","url":"lustre/effect.html#Effect"},{"doc":"lustre/effect","title":"batch","content":"pub fn batch(effects: List(Effect(a))) -&gt; Effect(a)\n\nSynonyms:\nlustre/effect.batch\nlustre/effect batch","url":"lustre/effect.html#batch"},{"doc":"lustre/effect","title":"from","content":"pub fn from(effect: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Effect(a)\n\nSynonyms:\nlustre/effect.from\nlustre/effect from","url":"lustre/effect.html#from"},{"doc":"lustre/effect","title":"map","content":"pub fn map(effect: Effect(a), f: fn(a) -&gt; b) -&gt; Effect(b)\n\nSynonyms:\nlustre/effect.map\nlustre/effect map","url":"lustre/effect.html#map"},{"doc":"lustre/effect","title":"none","content":"pub fn none() -&gt; Effect(a)\n Typically our app&#39;s `update` function needs to return a tuple of\n `#(model, Effect(msg))`. When we don&#39;t need to perform any side effects we\n can just return `none()`!\n\nSynonyms:\nlustre/effect.none\nlustre/effect none","url":"lustre/effect.html#none"},{"doc":"lustre/effect","title":"lustre/effect","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/effect](https://lustre.build/api/lustre/effect)","url":"lustre/effect.html"},{"doc":"lustre/attribute","title":"Attribute","content":"pub opaque type Attribute(msg)\n\n\nSynonyms:\nlustre/attribute.Attribute\nlustre/attribute Attribute","url":"lustre/attribute.html#Attribute"},{"doc":"lustre/attribute","title":"accept","content":"pub fn accept(types: List(String)) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.accept\nlustre/attribute accept","url":"lustre/attribute.html#accept"},{"doc":"lustre/attribute","title":"accept_charset","content":"pub fn accept_charset(types: List(String)) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.accept_charset\nlustre/attribute accept_charset","url":"lustre/attribute.html#accept_charset"},{"doc":"lustre/attribute","title":"alt","content":"pub fn alt(text: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.alt\nlustre/attribute alt","url":"lustre/attribute.html#alt"},{"doc":"lustre/attribute","title":"attribute","content":"pub fn attribute(name: String, value: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.attribute\nlustre/attribute attribute","url":"lustre/attribute.html#attribute"},{"doc":"lustre/attribute","title":"autocomplete","content":"pub fn autocomplete(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autocomplete\nlustre/attribute autocomplete","url":"lustre/attribute.html#autocomplete"},{"doc":"lustre/attribute","title":"autofocus","content":"pub fn autofocus(should_autofocus: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autofocus\nlustre/attribute autofocus","url":"lustre/attribute.html#autofocus"},{"doc":"lustre/attribute","title":"autoplay","content":"pub fn autoplay(should_autoplay: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autoplay\nlustre/attribute autoplay","url":"lustre/attribute.html#autoplay"},{"doc":"lustre/attribute","title":"checked","content":"pub fn checked(is_checked: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.checked\nlustre/attribute checked","url":"lustre/attribute.html#checked"},{"doc":"lustre/attribute","title":"class","content":"pub fn class(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.class\nlustre/attribute class","url":"lustre/attribute.html#class"},{"doc":"lustre/attribute","title":"classes","content":"pub fn classes(names: List(#(String, Bool))) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.classes\nlustre/attribute classes","url":"lustre/attribute.html#classes"},{"doc":"lustre/attribute","title":"cols","content":"pub fn cols(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.cols\nlustre/attribute cols","url":"lustre/attribute.html#cols"},{"doc":"lustre/attribute","title":"controls","content":"pub fn controls(visible: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.controls\nlustre/attribute controls","url":"lustre/attribute.html#controls"},{"doc":"lustre/attribute","title":"disabled","content":"pub fn disabled(is_disabled: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.disabled\nlustre/attribute disabled","url":"lustre/attribute.html#disabled"},{"doc":"lustre/attribute","title":"download","content":"pub fn download(filename: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.download\nlustre/attribute download","url":"lustre/attribute.html#download"},{"doc":"lustre/attribute","title":"for","content":"pub fn for(id: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.for\nlustre/attribute for","url":"lustre/attribute.html#for"},{"doc":"lustre/attribute","title":"height","content":"pub fn height(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.height\nlustre/attribute height","url":"lustre/attribute.html#height"},{"doc":"lustre/attribute","title":"href","content":"pub fn href(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.href\nlustre/attribute href","url":"lustre/attribute.html#href"},{"doc":"lustre/attribute","title":"id","content":"pub fn id(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.id\nlustre/attribute id","url":"lustre/attribute.html#id"},{"doc":"lustre/attribute","title":"loop","content":"pub fn loop(should_loop: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.loop\nlustre/attribute loop","url":"lustre/attribute.html#loop"},{"doc":"lustre/attribute","title":"map","content":"pub fn map(attr: Attribute(a), f: fn(a) -&gt; b) -&gt; Attribute(b)\n \nSynonyms:\nlustre/attribute.map\nlustre/attribute map","url":"lustre/attribute.html#map"},{"doc":"lustre/attribute","title":"max","content":"pub fn max(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.max\nlustre/attribute max","url":"lustre/attribute.html#max"},{"doc":"lustre/attribute","title":"min","content":"pub fn min(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.min\nlustre/attribute min","url":"lustre/attribute.html#min"},{"doc":"lustre/attribute","title":"msg","content":"pub fn msg(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.msg\nlustre/attribute msg","url":"lustre/attribute.html#msg"},{"doc":"lustre/attribute","title":"name","content":"pub fn name(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.name\nlustre/attribute name","url":"lustre/attribute.html#name"},{"doc":"lustre/attribute","title":"on","content":"pub fn on(name: String, handler: fn(Dynamic) -&gt; Result(a, b)) -&gt; Attribute(\n  a,\n)\n\nSynonyms:\nlustre/attribute.on\nlustre/attribute on","url":"lustre/attribute.html#on"},{"doc":"lustre/attribute","title":"pattern","content":"pub fn pattern(regex: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.pattern\nlustre/attribute pattern","url":"lustre/attribute.html#pattern"},{"doc":"lustre/attribute","title":"placeholder","content":"pub fn placeholder(text: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.placeholder\nlustre/attribute placeholder","url":"lustre/attribute.html#placeholder"},{"doc":"lustre/attribute","title":"property","content":"pub fn property(name: String, value: a) -&gt; Attribute(b)\n \nSynonyms:\nlustre/attribute.property\nlustre/attribute property","url":"lustre/attribute.html#property"},{"doc":"lustre/attribute","title":"readonly","content":"pub fn readonly(is_readonly: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.readonly\nlustre/attribute readonly","url":"lustre/attribute.html#readonly"},{"doc":"lustre/attribute","title":"rel","content":"pub fn rel(relationship: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.rel\nlustre/attribute rel","url":"lustre/attribute.html#rel"},{"doc":"lustre/attribute","title":"required","content":"pub fn required(is_required: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.required\nlustre/attribute required","url":"lustre/attribute.html#required"},{"doc":"lustre/attribute","title":"rows","content":"pub fn rows(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.rows\nlustre/attribute rows","url":"lustre/attribute.html#rows"},{"doc":"lustre/attribute","title":"selected","content":"pub fn selected(is_selected: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.selected\nlustre/attribute selected","url":"lustre/attribute.html#selected"},{"doc":"lustre/attribute","title":"src","content":"pub fn src(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.src\nlustre/attribute src","url":"lustre/attribute.html#src"},{"doc":"lustre/attribute","title":"step","content":"pub fn step(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.step\nlustre/attribute step","url":"lustre/attribute.html#step"},{"doc":"lustre/attribute","title":"style","content":"pub fn style(properties: List(#(String, String))) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.style\nlustre/attribute style","url":"lustre/attribute.html#style"},{"doc":"lustre/attribute","title":"target","content":"pub fn target(target: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.target\nlustre/attribute target","url":"lustre/attribute.html#target"},{"doc":"lustre/attribute","title":"to_string","content":"pub fn to_string(attr: Attribute(a)) -&gt; String\n\n \nSynonyms:\nlustre/attribute.to_string\nlustre/attribute to_string","url":"lustre/attribute.html#to_string"},{"doc":"lustre/attribute","title":"to_string_builder","content":"pub fn to_string_builder(attr: Attribute(a)) -&gt; StringBuilder\n\nSynonyms:\nlustre/attribute.to_string_builder\nlustre/attribute to_string_builder","url":"lustre/attribute.html#to_string_builder"},{"doc":"lustre/attribute","title":"to_string_parts","content":"pub fn to_string_parts(attr: Attribute(a)) -&gt; Result(\n  #(String, String),\n  Nil,\n)\n\n \nSynonyms:\nlustre/attribute.to_string_parts\nlustre/attribute to_string_parts","url":"lustre/attribute.html#to_string_parts"},{"doc":"lustre/attribute","title":"type_","content":"pub fn type_(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.type_\nlustre/attribute type_","url":"lustre/attribute.html#type_"},{"doc":"lustre/attribute","title":"value","content":"pub fn value(val: Dynamic) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.value\nlustre/attribute value","url":"lustre/attribute.html#value"},{"doc":"lustre/attribute","title":"width","content":"pub fn width(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.width\nlustre/attribute width","url":"lustre/attribute.html#width"},{"doc":"lustre/attribute","title":"wrap","content":"pub fn wrap(mode: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.wrap\nlustre/attribute wrap","url":"lustre/attribute.html#wrap"},{"doc":"lustre/attribute","title":"lustre/attribute","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/attribute](https://lustre.build/api/lustre/attribute)","url":"lustre/attribute.html"},{"doc":"lustre/element","title":"Element","content":"pub opaque type Element(msg)\n \n\nSynonyms:\nlustre/element.Element\nlustre/element Element","url":"lustre/element.html#Element"},{"doc":"lustre/element","title":"element","content":"pub fn element(tag: String, attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element.element\nlustre/element element","url":"lustre/element.html#element"},{"doc":"lustre/element","title":"map","content":"pub fn map(element: Element(a), f: fn(a) -&gt; b) -&gt; Element(b)\n \nSynonyms:\nlustre/element.map\nlustre/element map","url":"lustre/element.html#map"},{"doc":"lustre/element","title":"namespaced","content":"pub fn namespaced(namespace: String, tag: String, attrs: List(\n    Attribute(a),\n  ), children: List(Element(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element.namespaced\nlustre/element namespaced","url":"lustre/element.html#namespaced"},{"doc":"lustre/element","title":"text","content":"pub fn text(content: String) -&gt; Element(a)\n \nSynonyms:\nlustre/element.text\nlustre/element text","url":"lustre/element.html#text"},{"doc":"lustre/element","title":"to_string","content":"pub fn to_string(element: Element(a)) -&gt; String\n \nSynonyms:\nlustre/element.to_string\nlustre/element to_string","url":"lustre/element.html#to_string"},{"doc":"lustre/element","title":"to_string_builder","content":"pub fn to_string_builder(element: Element(a)) -&gt; StringBuilder\n\nSynonyms:\nlustre/element.to_string_builder\nlustre/element to_string_builder","url":"lustre/element.html#to_string_builder"},{"doc":"lustre/element","title":"to_string_builder_helper","content":"pub fn to_string_builder_helper(element: Element(a), raw_text: Bool) -&gt; StringBuilder\n \nSynonyms:\nlustre/element.to_string_builder_helper\nlustre/element to_string_builder_helper","url":"lustre/element.html#to_string_builder_helper"},{"doc":"lustre/element","title":"lustre/element","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/element](https://lustre.build/api/lustre/element)","url":"lustre/element.html"},{"doc":"lustre","title":"App","content":"pub opaque type App(flags, model, msg)\n\n\n\nSynonyms:\nlustre.App\nlustre App","url":"lustre.html#App"},{"doc":"lustre","title":"Error","content":"pub type Error {\n  AppAlreadyStarted\n  AppNotYetStarted\n  BadComponentName\n  ComponentAlreadyRegistered\n  ElementNotFound\n  NotABrowser\n}\n\nAppAlreadyStarted\n\n\nAppNotYetStarted\n\n\nBadComponentName\n\n\nComponentAlreadyRegistered\n\n\nElementNotFound\n\n\nNotABrowser\n\n\nSynonyms:\nlustre.Error\nlustre Error","url":"lustre.html#Error"},{"doc":"lustre","title":"application","content":"pub fn application(_init: fn(a) -&gt; #(b, Effect(c)), _update: fn(\n    b,\n    c,\n  ) -&gt; #(b, Effect(c)), _view: fn(b) -&gt; Element(c)) -&gt; App(\n  a,\n  b,\n  c,\n)\n\nSynonyms:\nlustre.application\nlustre application","url":"lustre.html#application"},{"doc":"lustre","title":"component","content":"pub fn component(_name: String, _init: fn() -&gt; #(a, Effect(b)), _update: fn(\n    a,\n    b,\n  ) -&gt; #(a, Effect(b)), _view: fn(a) -&gt; Element(b), _on_attribute_change: Map(\n    String,\n    fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  )) -&gt; Result(Nil, Error)\n\nSynonyms:\nlustre.component\nlustre component","url":"lustre.html#component"},{"doc":"lustre","title":"destroy","content":"pub fn destroy(_app: App(a, b, c)) -&gt; Result(Nil, Error)\n\nSynonyms:\nlustre.destroy\nlustre destroy","url":"lustre.html#destroy"},{"doc":"lustre","title":"element","content":"pub fn element(element: Element(a)) -&gt; App(Nil, Nil, a)\n\nSynonyms:\nlustre.element\nlustre element","url":"lustre.html#element"},{"doc":"lustre","title":"is_browser","content":"pub fn is_browser() -&gt; Bool\n\nSynonyms:\nlustre.is_browser\nlustre is_browser","url":"lustre.html#is_browser"},{"doc":"lustre","title":"is_registered","content":"pub fn is_registered(_name: String) -&gt; Bool\n\nSynonyms:\nlustre.is_registered\nlustre is_registered","url":"lustre.html#is_registered"},{"doc":"lustre","title":"simple","content":"pub fn simple(init: fn(a) -&gt; b, update: fn(b, c) -&gt; b, view: fn(b) -&gt;\n    Element(c)) -&gt; App(a, b, c)\n\nSynonyms:\nlustre.simple\nlustre simple","url":"lustre.html#simple"},{"doc":"lustre","title":"start","content":"pub fn start(_app: App(a, b, c), _selector: String, _flags: a) -&gt; Result(\n  fn(c) -&gt; Nil,\n  Error,\n)\n\nSynonyms:\nlustre.start\nlustre start","url":"lustre.html#start"},{"doc":"lustre","title":"lustre","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre](https://lustre.build/api/lustre)","url":"lustre.html"},{"doc":"lustre/event","title":"checked","content":"pub fn checked(event: Dynamic) -&gt; Result(Bool, List(DecodeError))\n\nSynonyms:\nlustre/event.checked\nlustre/event checked","url":"lustre/event.html#checked"},{"doc":"lustre/event","title":"emit","content":"pub fn emit(_event: String, _data: a) -&gt; Effect(b)\n\nSynonyms:\nlustre/event.emit\nlustre/event emit","url":"lustre/event.html#emit"},{"doc":"lustre/event","title":"mouse_position","content":"pub fn mouse_position(event: Dynamic) -&gt; Result(\n  #(Float, Float),\n  List(DecodeError),\n)\n\nSynonyms:\nlustre/event.mouse_position\nlustre/event mouse_position","url":"lustre/event.html#mouse_position"},{"doc":"lustre/event","title":"on","content":"pub fn on(name: String, handler: fn(Dynamic) -&gt; Result(a, b)) -&gt; Attribute(\n  a,\n)\n\nSynonyms:\nlustre/event.on\nlustre/event on","url":"lustre/event.html#on"},{"doc":"lustre/event","title":"on_blur","content":"pub fn on_blur(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_blur\nlustre/event on_blur","url":"lustre/event.html#on_blur"},{"doc":"lustre/event","title":"on_check","content":"pub fn on_check(msg: fn(Bool) -&gt; a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_check\nlustre/event on_check","url":"lustre/event.html#on_check"},{"doc":"lustre/event","title":"on_click","content":"pub fn on_click(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_click\nlustre/event on_click","url":"lustre/event.html#on_click"},{"doc":"lustre/event","title":"on_focus","content":"pub fn on_focus(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_focus\nlustre/event on_focus","url":"lustre/event.html#on_focus"},{"doc":"lustre/event","title":"on_input","content":"pub fn on_input(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_input\nlustre/event on_input","url":"lustre/event.html#on_input"},{"doc":"lustre/event","title":"on_keydown","content":"pub fn on_keydown(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key dow events on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre/event.on_keydown\nlustre/event on_keydown","url":"lustre/event.html#on_keydown"},{"doc":"lustre/event","title":"on_keypress","content":"pub fn on_keypress(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key presses on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre/event.on_keypress\nlustre/event on_keypress","url":"lustre/event.html#on_keypress"},{"doc":"lustre/event","title":"on_keyup","content":"pub fn on_keyup(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key up events on an element, and dispatches a message with the\n current key being released.\n\nSynonyms:\nlustre/event.on_keyup\nlustre/event on_keyup","url":"lustre/event.html#on_keyup"},{"doc":"lustre/event","title":"on_mouse_down","content":"pub fn on_mouse_down(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_down\nlustre/event on_mouse_down","url":"lustre/event.html#on_mouse_down"},{"doc":"lustre/event","title":"on_mouse_enter","content":"pub fn on_mouse_enter(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_enter\nlustre/event on_mouse_enter","url":"lustre/event.html#on_mouse_enter"},{"doc":"lustre/event","title":"on_mouse_leave","content":"pub fn on_mouse_leave(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_leave\nlustre/event on_mouse_leave","url":"lustre/event.html#on_mouse_leave"},{"doc":"lustre/event","title":"on_mouse_out","content":"pub fn on_mouse_out(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_out\nlustre/event on_mouse_out","url":"lustre/event.html#on_mouse_out"},{"doc":"lustre/event","title":"on_mouse_over","content":"pub fn on_mouse_over(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_over\nlustre/event on_mouse_over","url":"lustre/event.html#on_mouse_over"},{"doc":"lustre/event","title":"on_mouse_up","content":"pub fn on_mouse_up(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_up\nlustre/event on_mouse_up","url":"lustre/event.html#on_mouse_up"},{"doc":"lustre/event","title":"on_submit","content":"pub fn on_submit(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_submit\nlustre/event on_submit","url":"lustre/event.html#on_submit"},{"doc":"lustre/event","title":"prevent_default","content":"pub fn prevent_default(_event: Dynamic) -&gt; Nil\n\nSynonyms:\nlustre/event.prevent_default\nlustre/event prevent_default","url":"lustre/event.html#prevent_default"},{"doc":"lustre/event","title":"stop_propagation","content":"pub fn stop_propagation(_event: Dynamic) -&gt; Nil\n\nSynonyms:\nlustre/event.stop_propagation\nlustre/event stop_propagation","url":"lustre/event.html#stop_propagation"},{"doc":"lustre/event","title":"value","content":"pub fn value(event: Dynamic) -&gt; Result(String, List(DecodeError))\n\nSynonyms:\nlustre/event.value\nlustre/event value","url":"lustre/event.html#value"},{"doc":"lustre/event","title":"lustre/event","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/event](https://lustre.build/api/lustre/event)","url":"lustre/event.html"},{"doc":"lustre/element/svg","title":"a","content":"pub fn a(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.a\nlustre/element/svg a","url":"lustre/element/svg.html#a"},{"doc":"lustre/element/svg","title":"animate","content":"pub fn animate(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.animate\nlustre/element/svg animate","url":"lustre/element/svg.html#animate"},{"doc":"lustre/element/svg","title":"animate_motion","content":"pub fn animate_motion(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.animate_motion\nlustre/element/svg animate_motion","url":"lustre/element/svg.html#animate_motion"},{"doc":"lustre/element/svg","title":"animate_transform","content":"pub fn animate_transform(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.animate_transform\nlustre/element/svg animate_transform","url":"lustre/element/svg.html#animate_transform"},{"doc":"lustre/element/svg","title":"circle","content":"pub fn circle(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.circle\nlustre/element/svg circle","url":"lustre/element/svg.html#circle"},{"doc":"lustre/element/svg","title":"clip_path","content":"pub fn clip_path(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.clip_path\nlustre/element/svg clip_path","url":"lustre/element/svg.html#clip_path"},{"doc":"lustre/element/svg","title":"defs","content":"pub fn defs(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.defs\nlustre/element/svg defs","url":"lustre/element/svg.html#defs"},{"doc":"lustre/element/svg","title":"desc","content":"pub fn desc(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.desc\nlustre/element/svg desc","url":"lustre/element/svg.html#desc"},{"doc":"lustre/element/svg","title":"ellipse","content":"pub fn ellipse(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.ellipse\nlustre/element/svg ellipse","url":"lustre/element/svg.html#ellipse"},{"doc":"lustre/element/svg","title":"fe_blend","content":"pub fn fe_blend(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_blend\nlustre/element/svg fe_blend","url":"lustre/element/svg.html#fe_blend"},{"doc":"lustre/element/svg","title":"fe_color_matrix","content":"pub fn fe_color_matrix(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_color_matrix\nlustre/element/svg fe_color_matrix","url":"lustre/element/svg.html#fe_color_matrix"},{"doc":"lustre/element/svg","title":"fe_component_transfer","content":"pub fn fe_component_transfer(attrs: List(Attribute(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.fe_component_transfer\nlustre/element/svg fe_component_transfer","url":"lustre/element/svg.html#fe_component_transfer"},{"doc":"lustre/element/svg","title":"fe_composite","content":"pub fn fe_composite(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_composite\nlustre/element/svg fe_composite","url":"lustre/element/svg.html#fe_composite"},{"doc":"lustre/element/svg","title":"fe_convolve_matrix","content":"pub fn fe_convolve_matrix(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_convolve_matrix\nlustre/element/svg fe_convolve_matrix","url":"lustre/element/svg.html#fe_convolve_matrix"},{"doc":"lustre/element/svg","title":"fe_diffuse_lighting","content":"pub fn fe_diffuse_lighting(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_diffuse_lighting\nlustre/element/svg fe_diffuse_lighting","url":"lustre/element/svg.html#fe_diffuse_lighting"},{"doc":"lustre/element/svg","title":"fe_displacement_map","content":"pub fn fe_displacement_map(attrs: List(Attribute(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.fe_displacement_map\nlustre/element/svg fe_displacement_map","url":"lustre/element/svg.html#fe_displacement_map"},{"doc":"lustre/element/svg","title":"fe_distant_light","content":"pub fn fe_distant_light(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_distant_light\nlustre/element/svg fe_distant_light","url":"lustre/element/svg.html#fe_distant_light"},{"doc":"lustre/element/svg","title":"fe_drop_shadow","content":"pub fn fe_drop_shadow(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_drop_shadow\nlustre/element/svg fe_drop_shadow","url":"lustre/element/svg.html#fe_drop_shadow"},{"doc":"lustre/element/svg","title":"fe_flood","content":"pub fn fe_flood(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_flood\nlustre/element/svg fe_flood","url":"lustre/element/svg.html#fe_flood"},{"doc":"lustre/element/svg","title":"fe_func_a","content":"pub fn fe_func_a(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_func_a\nlustre/element/svg fe_func_a","url":"lustre/element/svg.html#fe_func_a"},{"doc":"lustre/element/svg","title":"fe_func_b","content":"pub fn fe_func_b(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_func_b\nlustre/element/svg fe_func_b","url":"lustre/element/svg.html#fe_func_b"},{"doc":"lustre/element/svg","title":"fe_func_g","content":"pub fn fe_func_g(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_func_g\nlustre/element/svg fe_func_g","url":"lustre/element/svg.html#fe_func_g"},{"doc":"lustre/element/svg","title":"fe_func_r","content":"pub fn fe_func_r(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_func_r\nlustre/element/svg fe_func_r","url":"lustre/element/svg.html#fe_func_r"},{"doc":"lustre/element/svg","title":"fe_gaussian_blur","content":"pub fn fe_gaussian_blur(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_gaussian_blur\nlustre/element/svg fe_gaussian_blur","url":"lustre/element/svg.html#fe_gaussian_blur"},{"doc":"lustre/element/svg","title":"fe_image","content":"pub fn fe_image(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_image\nlustre/element/svg fe_image","url":"lustre/element/svg.html#fe_image"},{"doc":"lustre/element/svg","title":"fe_merge","content":"pub fn fe_merge(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_merge\nlustre/element/svg fe_merge","url":"lustre/element/svg.html#fe_merge"},{"doc":"lustre/element/svg","title":"fe_merge_node","content":"pub fn fe_merge_node(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_merge_node\nlustre/element/svg fe_merge_node","url":"lustre/element/svg.html#fe_merge_node"},{"doc":"lustre/element/svg","title":"fe_morphology","content":"pub fn fe_morphology(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_morphology\nlustre/element/svg fe_morphology","url":"lustre/element/svg.html#fe_morphology"},{"doc":"lustre/element/svg","title":"fe_offset","content":"pub fn fe_offset(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_offset\nlustre/element/svg fe_offset","url":"lustre/element/svg.html#fe_offset"},{"doc":"lustre/element/svg","title":"fe_point_light","content":"pub fn fe_point_light(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_point_light\nlustre/element/svg fe_point_light","url":"lustre/element/svg.html#fe_point_light"},{"doc":"lustre/element/svg","title":"fe_specular_lighting","content":"pub fn fe_specular_lighting(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_specular_lighting\nlustre/element/svg fe_specular_lighting","url":"lustre/element/svg.html#fe_specular_lighting"},{"doc":"lustre/element/svg","title":"fe_spot_light","content":"pub fn fe_spot_light(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_spot_light\nlustre/element/svg fe_spot_light","url":"lustre/element/svg.html#fe_spot_light"},{"doc":"lustre/element/svg","title":"fe_tile","content":"pub fn fe_tile(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_tile\nlustre/element/svg fe_tile","url":"lustre/element/svg.html#fe_tile"},{"doc":"lustre/element/svg","title":"fe_turbulence","content":"pub fn fe_turbulence(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.fe_turbulence\nlustre/element/svg fe_turbulence","url":"lustre/element/svg.html#fe_turbulence"},{"doc":"lustre/element/svg","title":"foreign_object","content":"pub fn foreign_object(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.foreign_object\nlustre/element/svg foreign_object","url":"lustre/element/svg.html#foreign_object"},{"doc":"lustre/element/svg","title":"g","content":"pub fn g(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.g\nlustre/element/svg g","url":"lustre/element/svg.html#g"},{"doc":"lustre/element/svg","title":"image","content":"pub fn image(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.image\nlustre/element/svg image","url":"lustre/element/svg.html#image"},{"doc":"lustre/element/svg","title":"line","content":"pub fn line(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.line\nlustre/element/svg line","url":"lustre/element/svg.html#line"},{"doc":"lustre/element/svg","title":"linear_gradient","content":"pub fn linear_gradient(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.linear_gradient\nlustre/element/svg linear_gradient","url":"lustre/element/svg.html#linear_gradient"},{"doc":"lustre/element/svg","title":"marker","content":"pub fn marker(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.marker\nlustre/element/svg marker","url":"lustre/element/svg.html#marker"},{"doc":"lustre/element/svg","title":"mask","content":"pub fn mask(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.mask\nlustre/element/svg mask","url":"lustre/element/svg.html#mask"},{"doc":"lustre/element/svg","title":"metadata","content":"pub fn metadata(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.metadata\nlustre/element/svg metadata","url":"lustre/element/svg.html#metadata"},{"doc":"lustre/element/svg","title":"missing_glyph","content":"pub fn missing_glyph(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.missing_glyph\nlustre/element/svg missing_glyph","url":"lustre/element/svg.html#missing_glyph"},{"doc":"lustre/element/svg","title":"mpath","content":"pub fn mpath(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.mpath\nlustre/element/svg mpath","url":"lustre/element/svg.html#mpath"},{"doc":"lustre/element/svg","title":"path","content":"pub fn path(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.path\nlustre/element/svg path","url":"lustre/element/svg.html#path"},{"doc":"lustre/element/svg","title":"pattern","content":"pub fn pattern(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.pattern\nlustre/element/svg pattern","url":"lustre/element/svg.html#pattern"},{"doc":"lustre/element/svg","title":"polygon","content":"pub fn polygon(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.polygon\nlustre/element/svg polygon","url":"lustre/element/svg.html#polygon"},{"doc":"lustre/element/svg","title":"polyline","content":"pub fn polyline(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.polyline\nlustre/element/svg polyline","url":"lustre/element/svg.html#polyline"},{"doc":"lustre/element/svg","title":"radial_gradient","content":"pub fn radial_gradient(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.radial_gradient\nlustre/element/svg radial_gradient","url":"lustre/element/svg.html#radial_gradient"},{"doc":"lustre/element/svg","title":"rect","content":"pub fn rect(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.rect\nlustre/element/svg rect","url":"lustre/element/svg.html#rect"},{"doc":"lustre/element/svg","title":"script","content":"pub fn script(attrs: List(Attribute(a)), js: String) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.script\nlustre/element/svg script","url":"lustre/element/svg.html#script"},{"doc":"lustre/element/svg","title":"set","content":"pub fn set(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.set\nlustre/element/svg set","url":"lustre/element/svg.html#set"},{"doc":"lustre/element/svg","title":"stop","content":"pub fn stop(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.stop\nlustre/element/svg stop","url":"lustre/element/svg.html#stop"},{"doc":"lustre/element/svg","title":"style","content":"pub fn style(attrs: List(Attribute(a)), css: String) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.style\nlustre/element/svg style","url":"lustre/element/svg.html#style"},{"doc":"lustre/element/svg","title":"svg","content":"pub fn svg(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.svg\nlustre/element/svg svg","url":"lustre/element/svg.html#svg"},{"doc":"lustre/element/svg","title":"switch","content":"pub fn switch(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.switch\nlustre/element/svg switch","url":"lustre/element/svg.html#switch"},{"doc":"lustre/element/svg","title":"symbol","content":"pub fn symbol(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.symbol\nlustre/element/svg symbol","url":"lustre/element/svg.html#symbol"},{"doc":"lustre/element/svg","title":"text","content":"pub fn text(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.text\nlustre/element/svg text","url":"lustre/element/svg.html#text"},{"doc":"lustre/element/svg","title":"text_path","content":"pub fn text_path(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.text_path\nlustre/element/svg text_path","url":"lustre/element/svg.html#text_path"},{"doc":"lustre/element/svg","title":"title","content":"pub fn title(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.title\nlustre/element/svg title","url":"lustre/element/svg.html#title"},{"doc":"lustre/element/svg","title":"tspan","content":"pub fn tspan(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/svg.tspan\nlustre/element/svg tspan","url":"lustre/element/svg.html#tspan"},{"doc":"lustre/element/svg","title":"use_","content":"pub fn use_(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/svg.use_\nlustre/element/svg use_","url":"lustre/element/svg.html#use_"},{"doc":"lustre/element/svg","title":"lustre/element/svg","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/element/svg](https://lustre.build/api/lustre/element/svg)","url":"lustre/element/svg.html"},{"doc":"lustre/element/html","title":"a","content":"pub fn a(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.a\nlustre/element/html a","url":"lustre/element/html.html#a"},{"doc":"lustre/element/html","title":"abbr","content":"pub fn abbr(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.abbr\nlustre/element/html abbr","url":"lustre/element/html.html#abbr"},{"doc":"lustre/element/html","title":"address","content":"pub fn address(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.address\nlustre/element/html address","url":"lustre/element/html.html#address"},{"doc":"lustre/element/html","title":"area","content":"pub fn area(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.area\nlustre/element/html area","url":"lustre/element/html.html#area"},{"doc":"lustre/element/html","title":"article","content":"pub fn article(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.article\nlustre/element/html article","url":"lustre/element/html.html#article"},{"doc":"lustre/element/html","title":"aside","content":"pub fn aside(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.aside\nlustre/element/html aside","url":"lustre/element/html.html#aside"},{"doc":"lustre/element/html","title":"audio","content":"pub fn audio(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.audio\nlustre/element/html audio","url":"lustre/element/html.html#audio"},{"doc":"lustre/element/html","title":"b","content":"pub fn b(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.b\nlustre/element/html b","url":"lustre/element/html.html#b"},{"doc":"lustre/element/html","title":"base","content":"pub fn base(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.base\nlustre/element/html base","url":"lustre/element/html.html#base"},{"doc":"lustre/element/html","title":"bdi","content":"pub fn bdi(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.bdi\nlustre/element/html bdi","url":"lustre/element/html.html#bdi"},{"doc":"lustre/element/html","title":"bdo","content":"pub fn bdo(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.bdo\nlustre/element/html bdo","url":"lustre/element/html.html#bdo"},{"doc":"lustre/element/html","title":"blockquote","content":"pub fn blockquote(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.blockquote\nlustre/element/html blockquote","url":"lustre/element/html.html#blockquote"},{"doc":"lustre/element/html","title":"body","content":"pub fn body(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.body\nlustre/element/html body","url":"lustre/element/html.html#body"},{"doc":"lustre/element/html","title":"br","content":"pub fn br(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.br\nlustre/element/html br","url":"lustre/element/html.html#br"},{"doc":"lustre/element/html","title":"button","content":"pub fn button(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.button\nlustre/element/html button","url":"lustre/element/html.html#button"},{"doc":"lustre/element/html","title":"canvas","content":"pub fn canvas(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.canvas\nlustre/element/html canvas","url":"lustre/element/html.html#canvas"},{"doc":"lustre/element/html","title":"caption","content":"pub fn caption(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.caption\nlustre/element/html caption","url":"lustre/element/html.html#caption"},{"doc":"lustre/element/html","title":"cite","content":"pub fn cite(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.cite\nlustre/element/html cite","url":"lustre/element/html.html#cite"},{"doc":"lustre/element/html","title":"code","content":"pub fn code(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.code\nlustre/element/html code","url":"lustre/element/html.html#code"},{"doc":"lustre/element/html","title":"col","content":"pub fn col(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.col\nlustre/element/html col","url":"lustre/element/html.html#col"},{"doc":"lustre/element/html","title":"colgroup","content":"pub fn colgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.colgroup\nlustre/element/html colgroup","url":"lustre/element/html.html#colgroup"},{"doc":"lustre/element/html","title":"data","content":"pub fn data(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.data\nlustre/element/html data","url":"lustre/element/html.html#data"},{"doc":"lustre/element/html","title":"datalist","content":"pub fn datalist(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.datalist\nlustre/element/html datalist","url":"lustre/element/html.html#datalist"},{"doc":"lustre/element/html","title":"dd","content":"pub fn dd(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.dd\nlustre/element/html dd","url":"lustre/element/html.html#dd"},{"doc":"lustre/element/html","title":"del","content":"pub fn del(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.del\nlustre/element/html del","url":"lustre/element/html.html#del"},{"doc":"lustre/element/html","title":"details","content":"pub fn details(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.details\nlustre/element/html details","url":"lustre/element/html.html#details"},{"doc":"lustre/element/html","title":"dfn","content":"pub fn dfn(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.dfn\nlustre/element/html dfn","url":"lustre/element/html.html#dfn"},{"doc":"lustre/element/html","title":"dialog","content":"pub fn dialog(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.dialog\nlustre/element/html dialog","url":"lustre/element/html.html#dialog"},{"doc":"lustre/element/html","title":"div","content":"pub fn div(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.div\nlustre/element/html div","url":"lustre/element/html.html#div"},{"doc":"lustre/element/html","title":"dl","content":"pub fn dl(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.dl\nlustre/element/html dl","url":"lustre/element/html.html#dl"},{"doc":"lustre/element/html","title":"dt","content":"pub fn dt(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.dt\nlustre/element/html dt","url":"lustre/element/html.html#dt"},{"doc":"lustre/element/html","title":"em","content":"pub fn em(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.em\nlustre/element/html em","url":"lustre/element/html.html#em"},{"doc":"lustre/element/html","title":"embed","content":"pub fn embed(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.embed\nlustre/element/html embed","url":"lustre/element/html.html#embed"},{"doc":"lustre/element/html","title":"fieldset","content":"pub fn fieldset(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.fieldset\nlustre/element/html fieldset","url":"lustre/element/html.html#fieldset"},{"doc":"lustre/element/html","title":"figcaption","content":"pub fn figcaption(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.figcaption\nlustre/element/html figcaption","url":"lustre/element/html.html#figcaption"},{"doc":"lustre/element/html","title":"figure","content":"pub fn figure(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.figure\nlustre/element/html figure","url":"lustre/element/html.html#figure"},{"doc":"lustre/element/html","title":"footer","content":"pub fn footer(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.footer\nlustre/element/html footer","url":"lustre/element/html.html#footer"},{"doc":"lustre/element/html","title":"form","content":"pub fn form(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.form\nlustre/element/html form","url":"lustre/element/html.html#form"},{"doc":"lustre/element/html","title":"h1","content":"pub fn h1(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h1\nlustre/element/html h1","url":"lustre/element/html.html#h1"},{"doc":"lustre/element/html","title":"h2","content":"pub fn h2(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h2\nlustre/element/html h2","url":"lustre/element/html.html#h2"},{"doc":"lustre/element/html","title":"h3","content":"pub fn h3(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h3\nlustre/element/html h3","url":"lustre/element/html.html#h3"},{"doc":"lustre/element/html","title":"h4","content":"pub fn h4(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h4\nlustre/element/html h4","url":"lustre/element/html.html#h4"},{"doc":"lustre/element/html","title":"h5","content":"pub fn h5(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h5\nlustre/element/html h5","url":"lustre/element/html.html#h5"},{"doc":"lustre/element/html","title":"h6","content":"pub fn h6(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.h6\nlustre/element/html h6","url":"lustre/element/html.html#h6"},{"doc":"lustre/element/html","title":"head","content":"pub fn head(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.head\nlustre/element/html head","url":"lustre/element/html.html#head"},{"doc":"lustre/element/html","title":"header","content":"pub fn header(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.header\nlustre/element/html header","url":"lustre/element/html.html#header"},{"doc":"lustre/element/html","title":"hgroup","content":"pub fn hgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.hgroup\nlustre/element/html hgroup","url":"lustre/element/html.html#hgroup"},{"doc":"lustre/element/html","title":"hr","content":"pub fn hr(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.hr\nlustre/element/html hr","url":"lustre/element/html.html#hr"},{"doc":"lustre/element/html","title":"html","content":"pub fn html(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.html\nlustre/element/html html","url":"lustre/element/html.html#html"},{"doc":"lustre/element/html","title":"i","content":"pub fn i(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.i\nlustre/element/html i","url":"lustre/element/html.html#i"},{"doc":"lustre/element/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.iframe\nlustre/element/html iframe","url":"lustre/element/html.html#iframe"},{"doc":"lustre/element/html","title":"img","content":"pub fn img(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.img\nlustre/element/html img","url":"lustre/element/html.html#img"},{"doc":"lustre/element/html","title":"input","content":"pub fn input(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.input\nlustre/element/html input","url":"lustre/element/html.html#input"},{"doc":"lustre/element/html","title":"ins","content":"pub fn ins(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.ins\nlustre/element/html ins","url":"lustre/element/html.html#ins"},{"doc":"lustre/element/html","title":"kbd","content":"pub fn kbd(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.kbd\nlustre/element/html kbd","url":"lustre/element/html.html#kbd"},{"doc":"lustre/element/html","title":"label","content":"pub fn label(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.label\nlustre/element/html label","url":"lustre/element/html.html#label"},{"doc":"lustre/element/html","title":"legend","content":"pub fn legend(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.legend\nlustre/element/html legend","url":"lustre/element/html.html#legend"},{"doc":"lustre/element/html","title":"li","content":"pub fn li(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.li\nlustre/element/html li","url":"lustre/element/html.html#li"},{"doc":"lustre/element/html","title":"link","content":"pub fn link(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.link\nlustre/element/html link","url":"lustre/element/html.html#link"},{"doc":"lustre/element/html","title":"main","content":"pub fn main(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.main\nlustre/element/html main","url":"lustre/element/html.html#main"},{"doc":"lustre/element/html","title":"map","content":"pub fn map(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used with &lt;area&gt; elements to define an image map (a clickable link area).\n \nSynonyms:\nlustre/element/html.map\nlustre/element/html map","url":"lustre/element/html.html#map"},{"doc":"lustre/element/html","title":"mark","content":"pub fn mark(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.mark\nlustre/element/html mark","url":"lustre/element/html.html#mark"},{"doc":"lustre/element/html","title":"math","content":"pub fn math(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.math\nlustre/element/html math","url":"lustre/element/html.html#math"},{"doc":"lustre/element/html","title":"menu","content":"pub fn menu(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.menu\nlustre/element/html menu","url":"lustre/element/html.html#menu"},{"doc":"lustre/element/html","title":"meta","content":"pub fn meta(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.meta\nlustre/element/html meta","url":"lustre/element/html.html#meta"},{"doc":"lustre/element/html","title":"meter","content":"pub fn meter(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.meter\nlustre/element/html meter","url":"lustre/element/html.html#meter"},{"doc":"lustre/element/html","title":"nav","content":"pub fn nav(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.nav\nlustre/element/html nav","url":"lustre/element/html.html#nav"},{"doc":"lustre/element/html","title":"noscript","content":"pub fn noscript(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.noscript\nlustre/element/html noscript","url":"lustre/element/html.html#noscript"},{"doc":"lustre/element/html","title":"object","content":"pub fn object(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.object\nlustre/element/html object","url":"lustre/element/html.html#object"},{"doc":"lustre/element/html","title":"ol","content":"pub fn ol(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n\nSynonyms:\nlustre/element/html.ol\nlustre/element/html ol","url":"lustre/element/html.html#ol"},{"doc":"lustre/element/html","title":"optgroup","content":"pub fn optgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.optgroup\nlustre/element/html optgroup","url":"lustre/element/html.html#optgroup"},{"doc":"lustre/element/html","title":"option","content":"pub fn option(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.option\nlustre/element/html option","url":"lustre/element/html.html#option"},{"doc":"lustre/element/html","title":"output","content":"pub fn output(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.output\nlustre/element/html output","url":"lustre/element/html.html#output"},{"doc":"lustre/element/html","title":"p","content":"pub fn p(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.p\nlustre/element/html p","url":"lustre/element/html.html#p"},{"doc":"lustre/element/html","title":"picture","content":"pub fn picture(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.picture\nlustre/element/html picture","url":"lustre/element/html.html#picture"},{"doc":"lustre/element/html","title":"portal","content":"pub fn portal(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.portal\nlustre/element/html portal","url":"lustre/element/html.html#portal"},{"doc":"lustre/element/html","title":"pre","content":"pub fn pre(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.pre\nlustre/element/html pre","url":"lustre/element/html.html#pre"},{"doc":"lustre/element/html","title":"progress","content":"pub fn progress(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.progress\nlustre/element/html progress","url":"lustre/element/html.html#progress"},{"doc":"lustre/element/html","title":"q","content":"pub fn q(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.q\nlustre/element/html q","url":"lustre/element/html.html#q"},{"doc":"lustre/element/html","title":"rp","content":"pub fn rp(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.rp\nlustre/element/html rp","url":"lustre/element/html.html#rp"},{"doc":"lustre/element/html","title":"rt","content":"pub fn rt(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.rt\nlustre/element/html rt","url":"lustre/element/html.html#rt"},{"doc":"lustre/element/html","title":"ruby","content":"pub fn ruby(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.ruby\nlustre/element/html ruby","url":"lustre/element/html.html#ruby"},{"doc":"lustre/element/html","title":"s","content":"pub fn s(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.s\nlustre/element/html s","url":"lustre/element/html.html#s"},{"doc":"lustre/element/html","title":"samp","content":"pub fn samp(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.samp\nlustre/element/html samp","url":"lustre/element/html.html#samp"},{"doc":"lustre/element/html","title":"script","content":"pub fn script(attrs: List(Attribute(a)), js: String) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.script\nlustre/element/html script","url":"lustre/element/html.html#script"},{"doc":"lustre/element/html","title":"search","content":"pub fn search(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.search\nlustre/element/html search","url":"lustre/element/html.html#search"},{"doc":"lustre/element/html","title":"section","content":"pub fn section(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.section\nlustre/element/html section","url":"lustre/element/html.html#section"},{"doc":"lustre/element/html","title":"select","content":"pub fn select(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.select\nlustre/element/html select","url":"lustre/element/html.html#select"},{"doc":"lustre/element/html","title":"slot","content":"pub fn slot(attrs: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nlustre/element/html.slot\nlustre/element/html slot","url":"lustre/element/html.html#slot"},{"doc":"lustre/element/html","title":"small","content":"pub fn small(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.small\nlustre/element/html small","url":"lustre/element/html.html#small"},{"doc":"lustre/element/html","title":"source","content":"pub fn source(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.source\nlustre/element/html source","url":"lustre/element/html.html#source"},{"doc":"lustre/element/html","title":"span","content":"pub fn span(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.span\nlustre/element/html span","url":"lustre/element/html.html#span"},{"doc":"lustre/element/html","title":"strong","content":"pub fn strong(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.strong\nlustre/element/html strong","url":"lustre/element/html.html#strong"},{"doc":"lustre/element/html","title":"style","content":"pub fn style(attrs: List(Attribute(a)), css: String) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.style\nlustre/element/html style","url":"lustre/element/html.html#style"},{"doc":"lustre/element/html","title":"sub","content":"pub fn sub(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.sub\nlustre/element/html sub","url":"lustre/element/html.html#sub"},{"doc":"lustre/element/html","title":"summary","content":"pub fn summary(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.summary\nlustre/element/html summary","url":"lustre/element/html.html#summary"},{"doc":"lustre/element/html","title":"sup","content":"pub fn sup(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.sup\nlustre/element/html sup","url":"lustre/element/html.html#sup"},{"doc":"lustre/element/html","title":"svg","content":"pub fn svg(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.svg\nlustre/element/html svg","url":"lustre/element/html.html#svg"},{"doc":"lustre/element/html","title":"table","content":"pub fn table(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.table\nlustre/element/html table","url":"lustre/element/html.html#table"},{"doc":"lustre/element/html","title":"tbody","content":"pub fn tbody(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.tbody\nlustre/element/html tbody","url":"lustre/element/html.html#tbody"},{"doc":"lustre/element/html","title":"td","content":"pub fn td(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.td\nlustre/element/html td","url":"lustre/element/html.html#td"},{"doc":"lustre/element/html","title":"template","content":"pub fn template(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.template\nlustre/element/html template","url":"lustre/element/html.html#template"},{"doc":"lustre/element/html","title":"textarea","content":"pub fn textarea(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.textarea\nlustre/element/html textarea","url":"lustre/element/html.html#textarea"},{"doc":"lustre/element/html","title":"tfoot","content":"pub fn tfoot(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.tfoot\nlustre/element/html tfoot","url":"lustre/element/html.html#tfoot"},{"doc":"lustre/element/html","title":"th","content":"pub fn th(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.th\nlustre/element/html th","url":"lustre/element/html.html#th"},{"doc":"lustre/element/html","title":"thead","content":"pub fn thead(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.thead\nlustre/element/html thead","url":"lustre/element/html.html#thead"},{"doc":"lustre/element/html","title":"time","content":"pub fn time(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.time\nlustre/element/html time","url":"lustre/element/html.html#time"},{"doc":"lustre/element/html","title":"title","content":"pub fn title(attrs: List(Attribute(a)), content: String) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.title\nlustre/element/html title","url":"lustre/element/html.html#title"},{"doc":"lustre/element/html","title":"tr","content":"pub fn tr(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.tr\nlustre/element/html tr","url":"lustre/element/html.html#tr"},{"doc":"lustre/element/html","title":"track","content":"pub fn track(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.track\nlustre/element/html track","url":"lustre/element/html.html#track"},{"doc":"lustre/element/html","title":"u","content":"pub fn u(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.u\nlustre/element/html u","url":"lustre/element/html.html#u"},{"doc":"lustre/element/html","title":"ul","content":"pub fn ul(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.ul\nlustre/element/html ul","url":"lustre/element/html.html#ul"},{"doc":"lustre/element/html","title":"var","content":"pub fn var(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.var\nlustre/element/html var","url":"lustre/element/html.html#var"},{"doc":"lustre/element/html","title":"video","content":"pub fn video(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n \nSynonyms:\nlustre/element/html.video\nlustre/element/html video","url":"lustre/element/html.html#video"},{"doc":"lustre/element/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute(a))) -&gt; Element(a)\n \nSynonyms:\nlustre/element/html.wbr\nlustre/element/html wbr","url":"lustre/element/html.html#wbr"},{"doc":"lustre/element/html","title":"lustre/element/html","content":" To read the full documentation for this module, please visit\n [https://lustre.build/api/lustre/element/html](https://lustre.build/api/lustre/element/html)","url":"lustre/element/html.html"}]);